==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/plugins/Input/cue/translations/cue_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Modul CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Soubory CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>O modulu CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Modul Qmmp CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Nastavení modulu CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Automatic file detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Kódování CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Autodetekce znakové sady</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Jazyk:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Výchozí kódování:</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Input/cue/translations/cue_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>Modul CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>Soubory CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>O modulu CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Modul Qmmp CUE</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Nastavení modulu CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Obecná nastavení</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation>Nahrávat i neplatné cue, je-li to možné</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>Kódování CUE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Autodetekce znakové sady</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Jazyk:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Výchozí kódování:</translation>
    </message>
</context>
</TS>
